==> haskell-hslua-packaging-2.3.1-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-JDqTJGkxtMKINxr1X5dwqB
key:                  hslua-packaging-2.3.1-JDqTJGkxtMKINxr1X5dwqB
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  aa64c3ba8f97f932b2837fc789d7530b
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-JDqTJGkxtMKINxr1X5dwqB
depends:
    base-4.17.2.1 containers-0.6.7
    hslua-core-2.3.1-2nzTvfsqVknCIzNS5qYfSv
    hslua-marshalling-2.3.1-3N0OYycMLCBGRAbv74DYBc
    hslua-objectorientation-2.3.0-Jd3jxm950ym4wgf9mGrDy
    hslua-typing-0.1.1-CCgaBLxQsm34cmgw0TNlOj mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-packaging-2.3.1-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-3kShUTSn7K918k9IqW8iOr
key:                  hslua-packaging-2.3.1-3kShUTSn7K918k9IqW8iOr
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  7334bd02df79d231cedc384c5a50b26b
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-3kShUTSn7K918k9IqW8iOr
depends:
    base-4.17.2.1 containers-0.6.7
    hslua-core-2.3.1-KVZAOBtyBRJJfQ9Z1lLe3O
    hslua-marshalling-2.3.1-AoiVt4uO5va6om9d9GjHrD
    hslua-objectorientation-2.3.0-HhOcS8NV3fn14I80iLY779
    hslua-typing-0.1.1-6DTAohVlHbD7HhMt2N2Sm0 mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
